from django.shortcuts import render ,redirect
from django.contrib.auth.decorators import login_required
from fournisseurs.models import Fournisseur
from fournisseurs.forms import FournisseurForm , form_validation_error
from django.contrib import messages
from factures.models import Facture
from commandes.models import Commande
from paiements.models import Paiement
from avisderecu.models import Avisderecu
import decimal
from django.db.models import Q
from core.decorators import allowed_users
# Create your views here.
@login_required(login_url="/login/")
@allowed_users(allowed_roles=['admingestion','assistante'])
def liste_fournisseurs(request):
    context = {}
    context['segment'] = 'fournisseurs'
    context['liste_fournisseurs'] = Fournisseur.objects.all().values().order_by('updated_at')

    return render(request, 'liste-fournisseurs.html', context)

@login_required(login_url="/login/")
@allowed_users(allowed_roles=['admingestion','assistante'])
def affiche_ajouter_fournisseur(request):
	context = {}
	context['segment'] = 'fournisseurs'
	return render(request, 'ajouter-fournisseurs.html', context)

@login_required(login_url="/login/")
@allowed_users(allowed_roles=['admingestion','assistante'])
def ajouter_fournisseur(request):
	if request.method == "POST":
		form = FournisseurForm(request.POST or None)
		if form.is_valid():
			print("is valid")
			form.save()
			last_fournisseur = Fournisseur.objects.last().id
			fournisseur = Fournisseur.objects.get(id = last_fournisseur)
			Fournisseur.objects.filter(id = last_fournisseur).update(status = "actif")	
			messages.success(request, 'fournisseur a été bien ajouté')
		else:
			print("is not valid")
			print(form_validation_error(form))
			messages.error(request, "Numero de telephone doit etre unique")


	return redirect('liste_fournisseurs')

@allowed_users(allowed_roles=['admingestion','assistante'])
@login_required(login_url="/login/")
def afficher_fournisseur(request):
		context = {}
		context['segment'] = 'fournisseurs'
		if request.method == "POST":
			id_fournisseur = request.POST.get('fournisseur');
		else :
			id_fournisseur = request.GET.get('000') 

		fournisseur = Fournisseur.objects.get(id = id_fournisseur)
		context['fournisseur'] = fournisseur


		factures = Facture.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse()
		commandes = Commande.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse()

		factures_f = Facture.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse().first()
		commandes_f = Commande.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse().first()
		
		liste_paiement =[]
		montan_impaye = 0
		reste = 0 
		for facture in factures :
			reste = reste + facture.reste
			montan_impaye = montan_impaye +  facture.reste
			if Paiement.objects.filter(facture = facture).exists() :
				paiements = Paiement.objects.filter(facture = facture)
				for p in paiements :
					liste_paiement.append(p)
		
		liste_avisdereception =[]
		for  c in commandes :
			if Avisderecu.objects.filter(commande = c).exists() :
				avisderecu = Avisderecu.objects.filter(commande = c)
				for av in avisderecu :
					liste_avisdereception.append(av)

		if 	len(liste_paiement) > 0	:	
			paiements_f = liste_paiement[len(liste_paiement)-1]
			context['last_paiement'] = paiements_f
		if 	len(liste_avisdereception) > 0	:	
			last_avisrec = liste_avisdereception[len(liste_avisdereception)-1]
			context['last_avirecu'] = last_avisrec


		context['reste'] = reste

		context['factures'] = factures
		context['commandes'] = commandes
		context['paiements'] = liste_paiement
		context['liste_avisdereception'] = liste_avisdereception

		
		context['last_commande'] = commandes_f
		context['factures_f'] = factures_f
		context['montan_impaye'] = montan_impaye



		return render(request, 'afficher-fournisseur.html', context)

@allowed_users(allowed_roles=['admingestion','assistante'])
@login_required(login_url="/login/")
def affiche_modifier_fournisseur(request):
	context = {}
	if request.method == "POST":
		id_fournisseur = request.POST.get('fournisseur');
		fournisseur = Fournisseur.objects.get(id = id_fournisseur)
		context['fournisseur'] = fournisseur

	return render(request, 'modifier-fournisseur.html', context)

@allowed_users(allowed_roles=['admingestion','assistante'])
@login_required(login_url="/login/")
def valider_modifier_fournisseur(request):
	if request.method == "POST":
			id_fournisseur = request.POST.get('fournisseur')
			fournisseur =Fournisseur.objects.get(id = id_fournisseur)
			nom = request.POST.get('nom')
			prenom = request.POST.get('prenom')
			telephone1 = request.POST.get('telephone1')
			telephone2 = request.POST.get('telephone2')
			adresse = request.POST.get('adresse')

			Fournisseur.objects.filter(id = id_fournisseur).update(nom = nom)
			Fournisseur.objects.filter(id = id_fournisseur).update(prenom = prenom)
			Fournisseur.objects.filter(id = id_fournisseur).update(telephone1 = telephone2)
			Fournisseur.objects.filter(id = id_fournisseur).update(telephone2 = telephone2)
			Fournisseur.objects.filter(id = id_fournisseur).update(adresse = adresse)

			
			messages.success(request, 'fournisseur a été bien modifier')

	return redirect('liste_fournisseurs')	

@allowed_users(allowed_roles=['admingestion','assistante'])
@login_required(login_url="/login/")
def supprimer_fournisseur(request):

	if request.method == "POST":
		id_fournisseur = request.POST.get('fournisseur')
		fournisseur = Fournisseur.objects.get(id = id_fournisseur)
		commandes = Commande.objects.filter(fournisseur = fournisseur)
		factures = Facture.objects.filter(fournisseur = fournisseur)
		if factures.exists() or commandes.exists() :
			messages.info(request, 'Ce contact ne peut pas être supprimé car il est associé à des transactions ou des documents')
		else :
			fournisseur.delete()
			messages.error(request, 'fournisseur a été bien supprimer')
	return redirect('liste_fournisseurs')

@allowed_users(allowed_roles=['admingestion','assistante'])
@login_required(login_url="/login/")
def afficher_fournisseur_fnct(request,f_id):
		context = {}
		context['segment'] = 'fournisseurs'
		id_fournisseur = int(f_id)	
		fournisseur = Fournisseur.objects.get(id = id_fournisseur)
		context['fournisseur'] = fournisseur

		address_fact = Address.objects.filter(fournisseur = fournisseur).filter(type_Ad = 'facturation').order_by('created_at').reverse()
		address_livr = Address.objects.filter(fournisseur = fournisseur).filter(type_Ad = 'livraison').order_by('created_at').reverse()
		personnes = Personne.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse()
		factures = Facture.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse()
		commandes = Commande.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse()

		factures_f = Facture.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse().first()
		commandes_f = Commande.objects.filter(fournisseur = fournisseur).order_by('created_at').reverse().first()
		
		liste_paiement =[]
		montan_impaye = 0
		reste = 0 
		for facture in factures :
			reste = reste + facture.reste
			montan_impaye = montan_impaye +  facture.reste
			if Paiement.objects.filter(facture = facture).exists() :
				paiements = Paiement.objects.filter(facture = facture)
				for p in paiements :
					liste_paiement.append(p)
		
		liste_avisdereception =[]
		for  c in commandes :
			if Avisderecu.objects.filter(commande = c).exists() :
				avisderecu = Avisderecu.objects.filter(commande = c)
				for av in avisderecu :
					liste_avisdereception.append(av)

		if 	len(liste_paiement) > 0	:	
			paiements_f = liste_paiement[len(liste_paiement)-1]
			context['last_paiement'] = paiements_f
		if 	len(liste_avisdereception) > 0	:	
			last_avisrec = liste_avisdereception[len(liste_avisdereception)-1]
			context['last_avirecu'] = last_avisrec

		context['address_fact'] = address_fact
		context['address_livr'] = address_livr
		context['liste_personnes'] = personnes
		context['reste'] = reste

		context['factures'] = factures
		context['commandes'] = commandes
		context['paiements'] = liste_paiement
		context['liste_avisdereception'] = liste_avisdereception

		
		context['last_commande'] = commandes_f
		context['factures_f'] = factures_f
		context['montan_impaye'] = montan_impaye


		return render(request, 'afficher-fournisseur.html', context)